==> react-firebase-hooks-0.1.0.tgz: package/es/database/useDatabaseList.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
// $FlowExpectedError: Pending proper flow types
import { useEffect, useState } from 'react';
import firebase from 'firebase/app';
import 'firebase/database';
import { isString } from '../util';
export default (function (pathOrRef) {
  var ref = isString(pathOrRef) ? firebase.database().ref(pathOrRef) : pathOrRef;

  var _useState = useState(false),
      error = _useState[0],
      setError = _useState[1];

  var _useState2 = useState(true),
      loading = _useState2[0],
      setLoading = _useState2[1]; // Combine keys and values in a single state hook to allow them to be manipulated together


  var _useState3 = useState({
    keys: [],
    values: []
  }),
      _useState3$ = _useState3[0],
      keys = _useState3$.keys,
      values = _useState3$.values,
      setKeysValues = _useState3[1];

  var onError = function onError(err) {
    setError(err);
    setLoading(false);
  };

  var onChildAdded = function onChildAdded(snapshot, previousKey) {
    setKeysValues(function (prevState) {
      var _addChild = addChild(prevState.keys, prevState.values, snapshot, previousKey),
          newKeys = _addChild.newKeys,
          newValues = _addChild.newValues;

      return {
        keys: newKeys,
        values: newValues
      };
    });
  };

  var onChildChanged = function onChildChanged(snapshot) {
    setKeysValues(function (prevState) {
      var index = prevState.keys.indexOf(snapshot.key);
      return _extends({}, prevState, {
        values: prevState.values.slice(0, index).concat([snapshot.val()], prevState.values.slice(index + 1))
      });
    });
  };

  var onChildMoved = function onChildMoved(snapshot, previousKey) {
    setKeysValues(function (prevState) {
      // Remove the child from it's previous location
      var _removeChild = removeChild(prevState.keys, prevState.values, snapshot),
          tempKeys = _removeChild.newKeys,
          tempValues = _removeChild.newValues; // Add the child into it's new location


      var _addChild2 = addChild(tempKeys, tempValues, snapshot, previousKey),
          newKeys = _addChild2.newKeys,
          newValues = _addChild2.newValues;

      return {
        keys: newKeys,
        values: newValues
      };
    });
  };

  var onChildRemoved = function onChildRemoved(snapshot) {
    setKeysValues(function (prevState) {
      var _removeChild2 = removeChild(prevState.keys, prevState.values, snapshot),
          newKeys = _removeChild2.newKeys,
          newValues = _removeChild2.newValues;

      return {
        keys: newKeys,
        values: newValues
      };
    });
  };

  useEffect(function () {
    // This is here to indicate that all the data has been successfully received
    ref.once('value', function () {
      setLoading(false);
    }, function (err) {
      setError(err);
    });
    ref.on('child_added', onChildAdded);
    ref.on('child_changed', onChildChanged);
    ref.on('child_moved', onChildMoved);
    ref.on('child_removed', onChildRemoved);
    return function () {
      ref.off('child_added', onChildAdded);
      ref.off('child_changed', onChildChanged);
      ref.off('child_moved', onChildMoved);
      ref.off('child_removed', onChildRemoved);
    };
  }, // TODO: Check if this works suitably for 'ref' parameters
  [pathOrRef]);
  return {
    error: error,
    list: values,
    loading: loading
  };
});

var addChild = function addChild(keys, values, snapshot, previousKey) {
  if (!previousKey) {
    // The child has been added to the start of the list
    return {
      newKeys: [snapshot.key].concat(keys),
      newValues: [snapshot.val()].concat(values)
    };
  } // Establish the index for the previous child in the list


  var index = keys.indexOf(previousKey); // Insert the item after the previous child

  return {
    newKeys: keys.slice(0, index + 1).concat([snapshot.key], keys.slice(index + 1)),
    newValues: values.slice(0, index + 1).concat([snapshot.val()], values.slice(index + 1))
  };
};

var removeChild = function removeChild(keys, values, snapshot) {
  var index = keys.indexOf(snapshot.key);
  return {
    newKeys: keys.slice(0, index).concat(keys.slice(index + 1)),
    newValues: values.slice(0, index).concat(values.slice(index + 1))
  };
};

==> react-firebase-hooks-0.2.0.tgz: package/es/database/useDatabaseList.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
// $FlowExpectedError: Pending proper flow types
import { useEffect, useState } from 'react';
import firebase from 'firebase/app';
import 'firebase/database';
import { isString } from '../util';
export default (function (pathOrRef) {
  var ref = isString(pathOrRef) ? firebase.database().ref(pathOrRef) : pathOrRef;

  var _useState = useState(false),
      error = _useState[0],
      setError = _useState[1];

  var _useState2 = useState(true),
      loading = _useState2[0],
      setLoading = _useState2[1]; // Combine keys and values in a single state hook to allow them to be manipulated together


  var _useState3 = useState({
    keys: [],
    values: []
  }),
      values = _useState3[0].values,
      setKeysValues = _useState3[1];

  var onChildAdded = function onChildAdded(snapshot, previousKey) {
    setKeysValues(function (prevState) {
      var _addChild = addChild(prevState.keys, prevState.values, snapshot, previousKey),
          newKeys = _addChild.newKeys,
          newValues = _addChild.newValues;

      return {
        keys: newKeys,
        values: newValues
      };
    });
  };

  var onChildChanged = function onChildChanged(snapshot) {
    setKeysValues(function (prevState) {
      var index = prevState.keys.indexOf(snapshot.key);
      return _extends({}, prevState, {
        values: prevState.values.slice(0, index).concat([snapshot], prevState.values.slice(index + 1))
      });
    });
  };

  var onChildMoved = function onChildMoved(snapshot, previousKey) {
    setKeysValues(function (prevState) {
      // Remove the child from it's previous location
      var _removeChild = removeChild(prevState.keys, prevState.values, snapshot),
          tempKeys = _removeChild.newKeys,
          tempValues = _removeChild.newValues; // Add the child into it's new location


      var _addChild2 = addChild(tempKeys, tempValues, snapshot, previousKey),
          newKeys = _addChild2.newKeys,
          newValues = _addChild2.newValues;

      return {
        keys: newKeys,
        values: newValues
      };
    });
  };

  var onChildRemoved = function onChildRemoved(snapshot) {
    setKeysValues(function (prevState) {
      var _removeChild2 = removeChild(prevState.keys, prevState.values, snapshot),
          newKeys = _removeChild2.newKeys,
          newValues = _removeChild2.newValues;

      return {
        keys: newKeys,
        values: newValues
      };
    });
  };

  useEffect(function () {
    // This is here to indicate that all the data has been successfully received
    ref.once('value', function () {
      setLoading(false);
    }, function (err) {
      setError(err);
      setLoading(false);
    });
    ref.on('child_added', onChildAdded);
    ref.on('child_changed', onChildChanged);
    ref.on('child_moved', onChildMoved);
    ref.on('child_removed', onChildRemoved);
    return function () {
      ref.off('child_added', onChildAdded);
      ref.off('child_changed', onChildChanged);
      ref.off('child_moved', onChildMoved);
      ref.off('child_removed', onChildRemoved);
    };
  }, // TODO: Check if this works suitably for 'ref' parameters
  [pathOrRef]);
  return {
    error: error,
    list: values,
    loading: loading
  };
});

var addChild = function addChild(keys, values, snapshot, previousKey) {
  if (!previousKey) {
    // The child has been added to the start of the list
    return {
      newKeys: [snapshot.key].concat(keys),
      newValues: [snapshot].concat(values)
    };
  } // Establish the index for the previous child in the list


  var index = keys.indexOf(previousKey); // Insert the item after the previous child

  return {
    newKeys: keys.slice(0, index + 1).concat([snapshot.key], keys.slice(index + 1)),
    newValues: values.slice(0, index + 1).concat([snapshot], values.slice(index + 1))
  };
};

var removeChild = function removeChild(keys, values, snapshot) {
  var index = keys.indexOf(snapshot.key);
  return {
    newKeys: keys.slice(0, index).concat(keys.slice(index + 1)),
    newValues: values.slice(0, index).concat(values.slice(index + 1))
  };
};
